==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/df/d3a/water_8h.js <==
var water_8h =
[
    [ "FloodingBehaviour", "df/d3a/water_8h.html#ac7d0c94e2e61e21f7384d4b9d590f95b", [
      [ "FLOOD_NONE", "df/d3a/water_8h.html#ac7d0c94e2e61e21f7384d4b9d590f95baa6cd9be2b807d59169c1a41f6a54cbbb", null ],
      [ "FLOOD_ACTIVE", "df/d3a/water_8h.html#ac7d0c94e2e61e21f7384d4b9d590f95babeb7241a56de07a0362f88d5283fe3f1", null ],
      [ "FLOOD_PASSIVE", "df/d3a/water_8h.html#ac7d0c94e2e61e21f7384d4b9d590f95badc8ae5570ce16409c0f8fba025bde25f", null ],
      [ "FLOOD_DRYUP", "df/d3a/water_8h.html#ac7d0c94e2e61e21f7384d4b9d590f95bac3f1f9f4bc82329eb5a5f6f7cdc1cdf6", null ]
    ] ],
    [ "CanalMaintenanceCost", "df/d3a/water_8h.html#ac4bf4de201ed6f424de7c3b5b79911bf", null ],
    [ "ConvertGroundTilesIntoWaterTiles", "df/d3a/water_8h.html#ae47a16dc90ab128c43792621a3eead21", null ],
    [ "DoFloodTile", "df/d3a/water_8h.html#ad4f40aad128c1d56c6ad3e8cef3edec2", null ],
    [ "DrawShipDepotSprite", "df/d3a/water_8h.html#a3cfe223ae0d687cc13afd955c42d99b4", null ],
    [ "DrawShoreTile", "df/d3a/water_8h.html#a9ba1102943a3ff8ce38914b13e995315", null ],
    [ "DrawWaterClassGround", "df/d3a/water_8h.html#a72444e599cd303502b47bc7014fce06b", null ],
    [ "FloodHalftile", "df/d3a/water_8h.html#a4af4ea5ec5560996188ee002147daee5", null ],
    [ "GetFloodingBehaviour", "df/d3a/water_8h.html#aa89301ace15cf15495d024e57a5492b7", null ],
    [ "IsWateredTile", "df/d3a/water_8h.html#ae3850302db24ae4188b1462472294ec6", null ],
    [ "MakeWaterKeepingClass", "df/d3a/water_8h.html#a296098610e7a0ee88a70360370aeb539", null ],
    [ "RiverModifyDesertZone", "df/d3a/water_8h.html#acc6e906fa557469fafa21ec37dfe4de4", null ],
    [ "TileLoop_Water", "df/d3a/water_8h.html#a0598ef57674c268cc65aee2693723a7d", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/df/d3a/water_8h.js <==
var water_8h =
[
    [ "FloodingBehaviour", "df/d3a/water_8h.html#ac7d0c94e2e61e21f7384d4b9d590f95b", [
      [ "FLOOD_NONE", "df/d3a/water_8h.html#ac7d0c94e2e61e21f7384d4b9d590f95baa6cd9be2b807d59169c1a41f6a54cbbb", null ],
      [ "FLOOD_ACTIVE", "df/d3a/water_8h.html#ac7d0c94e2e61e21f7384d4b9d590f95babeb7241a56de07a0362f88d5283fe3f1", null ],
      [ "FLOOD_PASSIVE", "df/d3a/water_8h.html#ac7d0c94e2e61e21f7384d4b9d590f95badc8ae5570ce16409c0f8fba025bde25f", null ],
      [ "FLOOD_DRYUP", "df/d3a/water_8h.html#ac7d0c94e2e61e21f7384d4b9d590f95bac3f1f9f4bc82329eb5a5f6f7cdc1cdf6", null ]
    ] ],
    [ "CanalMaintenanceCost", "df/d3a/water_8h.html#ac4bf4de201ed6f424de7c3b5b79911bf", null ],
    [ "CheckForDockingTile", "df/d3a/water_8h.html#aaca5050130c73cf5e61b6feb1c391837", null ],
    [ "ConvertGroundTilesIntoWaterTiles", "df/d3a/water_8h.html#ae47a16dc90ab128c43792621a3eead21", null ],
    [ "DoFloodTile", "df/d3a/water_8h.html#ad4f40aad128c1d56c6ad3e8cef3edec2", null ],
    [ "DrawShipDepotSprite", "df/d3a/water_8h.html#a3cfe223ae0d687cc13afd955c42d99b4", null ],
    [ "DrawShoreTile", "df/d3a/water_8h.html#a9ba1102943a3ff8ce38914b13e995315", null ],
    [ "DrawWaterClassGround", "df/d3a/water_8h.html#a72444e599cd303502b47bc7014fce06b", null ],
    [ "FloodHalftile", "df/d3a/water_8h.html#a4af4ea5ec5560996188ee002147daee5", null ],
    [ "GetFloodingBehaviour", "df/d3a/water_8h.html#aa89301ace15cf15495d024e57a5492b7", null ],
    [ "IsWateredTile", "df/d3a/water_8h.html#ae3850302db24ae4188b1462472294ec6", null ],
    [ "MakeWaterKeepingClass", "df/d3a/water_8h.html#a296098610e7a0ee88a70360370aeb539", null ],
    [ "RiverModifyDesertZone", "df/d3a/water_8h.html#acc6e906fa557469fafa21ec37dfe4de4", null ],
    [ "TileLoop_Water", "df/d3a/water_8h.html#a0598ef57674c268cc65aee2693723a7d", null ],
    [ "RIVER_OFFSET_DESERT_DISTANCE", "df/d3a/water_8h.html#abf9f64f55a083c40007b9043f9c7b65b", null ]
];
